@@ -23,10 +23,9 @@
  *   <img src="breakpoint-bin.png" alt="breakpoint-bin">
  * </picture>
  *
- * `AdwBreakpointBin` provides a way to use breakpoints without [class@Window],
- * [class@ApplicationWindow] or [class@Dialog]. It can be useful for limiting
- * breakpoints to a single page and similar purposes. Most applications
- * shouldn't need it.
+ * `AdwBreakpointBin` provides a way to use breakpoints without [class@Window]
+ * or [class@ApplicationWindow]. It can be useful for limiting breakpoints to a
+ * single page and similar purposes. Most applications shouldn't need it.
  *
  * `AdwBreakpointBin` is similar to [class@Bin]. It has one child, set via the
  * [property@BreakpointBin:child] property.
@@ -131,11 +130,6 @@
  * Since: 1.4
  */
 
-typedef struct {
-  gboolean grab_focus;
-  GtkDirectionType direction;
-} DelayedFocus;
-
 typedef struct
 {
   GtkWidget *child;
@@ -149,16 +143,6 @@ typedef struct
 
   gboolean block_warnings;
   GtkWidget *warning_widget;
-  gboolean enable_min_size_warnings;
-  gboolean enable_overflow_warnings;
-
-  gboolean pass_through;
-
-  int natural_width;
-  int natural_height;
-
-  GtkWidget *last_focus;
-  GArray *delayed_focus;
 } AdwBreakpointBinPrivate;
 
 static void adw_breakpoint_bin_buildable_init (GtkBuildableIface *iface);
@@ -193,7 +177,7 @@ allocate_child (AdwBreakpointBin *self,
   if (!priv->child)
     return;
 
-  if (!priv->block_warnings && priv->breakpoints && priv->enable_min_size_warnings) {
+  if (!priv->block_warnings && priv->breakpoints) {
     int window_width, window_height;
     GtkWidget *warning_widget;
 
@@ -206,16 +190,13 @@ allocate_child (AdwBreakpointBin *self,
                                  &window_width, &window_height);
 
     if (window_width <= 0 && window_height <= 0)
-      g_warning ("%s %p does not have a minimum size, set the 'width-request' "
-                 "and 'height-request' properties to specify it",
+      g_warning ("%s %p does not have a minimum size",
                  G_OBJECT_TYPE_NAME (warning_widget), warning_widget);
     else if (window_width <= 0)
-      g_warning ("%s %p does not have a minimum width, set the "
-                 "'width-request' property to specify it",
+      g_warning ("%s %p does not have a minimum width",
                  G_OBJECT_TYPE_NAME (warning_widget), warning_widget);
     else if (window_height <= 0)
-      g_warning ("%s %p does not have a minimum height, set the "
-                 "'height-request' property to specify it",
+      g_warning ("%s %p does not have a minimum height",
                  G_OBJECT_TYPE_NAME (warning_widget), warning_widget);
   }
 
@@ -230,7 +211,7 @@ allocate_child (AdwBreakpointBin *self,
     return;
   }
 
-  if (!priv->block_warnings && priv->enable_overflow_warnings) {
+  if (!priv->block_warnings) {
     GtkWidget *warning_widget;
 
     if (priv->warning_widget)
@@ -264,52 +245,15 @@ breakpoint_changed_tick_cb (GtkWidget        *widget,
                             AdwBreakpointBin *self)
 {
   AdwBreakpointBinPrivate *priv = adw_breakpoint_bin_get_instance_private (self);
-  int i;
 
   priv->tick_cb_id = 0;
-  g_clear_pointer (&priv->old_node, gsk_render_node_unref);
+  priv->old_node = NULL;
   gtk_widget_set_child_visible (priv->child, TRUE);
   gtk_widget_queue_resize (GTK_WIDGET (self));
 
-  if (priv->last_focus) {
-    gtk_widget_grab_focus (priv->last_focus);
-    g_clear_weak_pointer (&priv->last_focus);
-  }
-
-  for (i = 0; i < priv->delayed_focus->len; i++) {
-    DelayedFocus *focus = &g_array_index (priv->delayed_focus, DelayedFocus, i);
-
-    if (focus->grab_focus)
-      gtk_widget_grab_focus (GTK_WIDGET (widget));
-    else
-      adw_widget_focus_child (GTK_WIDGET (widget), focus->direction);
-  }
-
-  g_array_remove_range (priv->delayed_focus, 0, priv->delayed_focus->len);
-
   return G_SOURCE_REMOVE;
 }
 
-static void
-breakpoint_notify_condition_cb (AdwBreakpointBin *self)
-{
-  gtk_widget_queue_allocate (GTK_WIDGET (self));
-}
-
-static gboolean
-adw_breakpoint_bin_contains (GtkWidget *widget,
-                             double     x,
-                             double     y)
-{
-  AdwBreakpointBin *self = ADW_BREAKPOINT_BIN (widget);
-  AdwBreakpointBinPrivate *priv = adw_breakpoint_bin_get_instance_private (self);
-
-  if (priv->pass_through)
-    return FALSE;
-
-  return GTK_WIDGET_CLASS (adw_breakpoint_bin_parent_class)->contains (widget, x, y);
-}
-
 static void
 adw_breakpoint_bin_snapshot (GtkWidget   *widget,
                              GtkSnapshot *snapshot)
@@ -352,27 +296,16 @@ adw_breakpoint_bin_measure (GtkWidget      *widget,
 {
   AdwBreakpointBin *self = ADW_BREAKPOINT_BIN (widget);
   AdwBreakpointBinPrivate *priv = adw_breakpoint_bin_get_instance_private (self);
-  int min = 0, nat = 0;
+  int min, nat;
 
-  if (priv->child) {
+  if (priv->child)
     gtk_widget_measure (priv->child, orientation, for_size,
                         &min, &nat, NULL, NULL);
+  else
+    min = nat = 0;
 
-    if (priv->breakpoints)
-      min = 0;
-  }
-
-  if (orientation == GTK_ORIENTATION_HORIZONTAL) {
-    if (priv->natural_width >= 0)
-      nat = MAX (min, priv->natural_width);
-    else
-      nat = MAX (min, nat);
-  } else {
-    if (priv->natural_height >= 0)
-      nat = MAX (min, priv->natural_height);
-    else
-      nat = MAX (min, nat);
-  }
+  if (priv->breakpoints)
+    min = 0;
 
   if (minimum)
     *minimum = min;
@@ -419,18 +352,6 @@ adw_breakpoint_bin_size_allocate (GtkWidget *widget,
   }
 
   if (!priv->first_allocation) {
-    GtkRoot *root = gtk_widget_get_root (widget);
-
-    if (root) {
-      GtkWidget *focus = gtk_root_get_focus (root);
-
-      if (focus && !gtk_widget_is_ancestor (focus, widget))
-        focus = NULL;
-
-      if (focus)
-        g_object_add_weak_pointer (G_OBJECT (focus), (gpointer *) &priv->last_focus);
-    }
-
     priv->block_warnings = TRUE;
     allocate_child (self, width, height, baseline);
     priv->block_warnings = FALSE;
@@ -471,53 +392,6 @@ adw_breakpoint_bin_map (GtkWidget *widget)
   GTK_WIDGET_CLASS (adw_breakpoint_bin_parent_class)->map (GTK_WIDGET (self));
 }
 
-static gboolean
-adw_breakpoint_bin_focus (GtkWidget        *widget,
-                          GtkDirectionType  direction)
-{
-  AdwBreakpointBin *self = ADW_BREAKPOINT_BIN (widget);
-  AdwBreakpointBinPrivate *priv = adw_breakpoint_bin_get_instance_private (self);
-
-  if (priv->tick_cb_id > 0) {
-    DelayedFocus focus;
-
-    focus.grab_focus = FALSE;
-    focus.direction = direction;
-
-    g_array_append_val (priv->delayed_focus, focus);
-
-    if (priv->last_focus)
-      g_clear_weak_pointer (&priv->last_focus);
-
-    return FALSE;
-  }
-
-  return adw_widget_focus_child (widget, direction);
-}
-
-static gboolean
-adw_breakpoint_bin_grab_focus (GtkWidget *widget)
-{
-  AdwBreakpointBin *self = ADW_BREAKPOINT_BIN (widget);
-  AdwBreakpointBinPrivate *priv = adw_breakpoint_bin_get_instance_private (self);
-
-  if (priv->tick_cb_id > 0) {
-    DelayedFocus focus;
-
-    focus.grab_focus = TRUE;
-    focus.direction = 0;
-
-    g_array_append_val (priv->delayed_focus, focus);
-
-    if (priv->last_focus)
-      g_clear_weak_pointer (&priv->last_focus);
-
-    return FALSE;
-  }
-
-  return adw_widget_grab_focus_child (widget);
-}
-
 static void
 adw_breakpoint_bin_dispose (GObject *object)
 {
@@ -536,8 +410,6 @@ adw_breakpoint_bin_dispose (GObject *object)
     priv->breakpoints = NULL;
   }
 
-  g_clear_pointer (&priv->delayed_focus, g_array_unref);
-
   G_OBJECT_CLASS (adw_breakpoint_bin_parent_class)->dispose (object);
 }
 
@@ -588,18 +460,15 @@ adw_breakpoint_bin_class_init (AdwBreakpointBinClass *klass)
   object_class->get_property = adw_breakpoint_bin_get_property;
   object_class->set_property = adw_breakpoint_bin_set_property;
 
-  widget_class->contains = adw_breakpoint_bin_contains;
   widget_class->get_request_mode = adw_breakpoint_bin_get_request_mode;
   widget_class->measure = adw_breakpoint_bin_measure;
   widget_class->size_allocate = adw_breakpoint_bin_size_allocate;
   widget_class->compute_expand = adw_widget_compute_expand;
   widget_class->snapshot = adw_breakpoint_bin_snapshot;
   widget_class->map = adw_breakpoint_bin_map;
-  widget_class->focus = adw_breakpoint_bin_focus;
-  widget_class->grab_focus = adw_breakpoint_bin_grab_focus;
 
   /**
-   * AdwBreakpointBin:child:
+   * AdwBreakpointBin:child: (attributes org.gtk.Property.get=adw_breakpoint_bin_get_child org.gtk.Property.set=adw_breakpoint_bin_set_child)
    *
    * The child widget.
    *
@@ -611,7 +480,7 @@ adw_breakpoint_bin_class_init (AdwBreakpointBinClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwBreakpointBin:current-breakpoint:
+   * AdwBreakpointBin:current-breakpoint: (attributes org.gtk.Property.get=adw_breakpoint_bin_get_current_breakpoint)
    *
    * The current breakpoint.
    *
@@ -628,15 +497,6 @@ adw_breakpoint_bin_class_init (AdwBreakpointBinClass *klass)
 static void
 adw_breakpoint_bin_init (AdwBreakpointBin *self)
 {
-  AdwBreakpointBinPrivate *priv = adw_breakpoint_bin_get_instance_private (self);
-
-  priv->natural_width = -1;
-  priv->natural_height = -1;
-  priv->enable_min_size_warnings = TRUE;
-  priv->enable_overflow_warnings = TRUE;
-
-  priv->delayed_focus = g_array_new (FALSE, FALSE, sizeof (DelayedFocus));
-
   gtk_widget_set_overflow (GTK_WIDGET (self), GTK_OVERFLOW_HIDDEN);
 }
 
@@ -679,7 +539,7 @@ adw_breakpoint_bin_new (void)
 }
 
 /**
- * adw_breakpoint_bin_get_child:
+ * adw_breakpoint_bin_get_child: (attributes org.gtk.Method.get_property=child)
  * @self: a breakpoint bin
  *
  * Gets the child widget of @self.
@@ -701,7 +561,7 @@ adw_breakpoint_bin_get_child (AdwBreakpointBin *self)
 }
 
 /**
- * adw_breakpoint_bin_set_child:
+ * adw_breakpoint_bin_set_child: (attributes org.gtk.Method.set_property=child)
  * @self: a breakpoint bin
  * @child: (nullable): the child widget
  *
@@ -718,26 +578,22 @@ adw_breakpoint_bin_set_child (AdwBreakpointBin *self,
   g_return_if_fail (ADW_IS_BREAKPOINT_BIN (self));
   g_return_if_fail (child == NULL || GTK_IS_WIDGET (child));
 
+  if (child)
+    g_return_if_fail (gtk_widget_get_parent (child) == NULL);
+
   priv = adw_breakpoint_bin_get_instance_private (self);
 
   if (priv->child == child)
     return;
 
-  if (child)
-    g_return_if_fail (gtk_widget_get_parent (child) == NULL);
-
   if (priv->child)
     gtk_widget_unparent (priv->child);
 
   priv->child = child;
 
-  if (child) {
+  if (child)
     gtk_widget_set_parent (child, GTK_WIDGET (self));
 
-    if (priv->old_node)
-      gtk_widget_set_child_visible (child, FALSE);
-  }
-
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_CHILD]);
 }
 
@@ -763,41 +619,14 @@ adw_breakpoint_bin_add_breakpoint (AdwBreakpointBin *self,
 
   priv->breakpoints = g_list_prepend (priv->breakpoints, breakpoint);
 
-  breakpoint_notify_condition_cb (self);
+  gtk_widget_queue_allocate (GTK_WIDGET (self));
 
   g_signal_connect_swapped (breakpoint, "notify::condition",
-                            G_CALLBACK (breakpoint_notify_condition_cb), self);
+                            G_CALLBACK (gtk_widget_queue_allocate), self);
 }
 
 /**
- * adw_breakpoint_bin_remove_breakpoint:
- * @self: a breakpoint bin
- * @breakpoint: a breakpoint to remove
- *
- * Removes @breakpoint from @self.
- *
- * Since: 1.5
- */
-void
-adw_breakpoint_bin_remove_breakpoint (AdwBreakpointBin *self,
-                                      AdwBreakpoint    *breakpoint)
-{
-  AdwBreakpointBinPrivate *priv;
-
-  g_return_if_fail (ADW_IS_BREAKPOINT_BIN (self));
-  g_return_if_fail (ADW_IS_BREAKPOINT (breakpoint));
-
-  priv = adw_breakpoint_bin_get_instance_private (self);
-
-  priv->breakpoints = g_list_remove (priv->breakpoints, breakpoint);
-
-  breakpoint_notify_condition_cb (self);
-
-  g_signal_handlers_disconnect_by_func (breakpoint, breakpoint_notify_condition_cb, self);
-}
-
-/**
- * adw_breakpoint_bin_get_current_breakpoint:
+ * adw_breakpoint_bin_get_current_breakpoint: (attributes org.gtk.Method.get_property=current-breakpoint)
  * @self: a breakpoint bin
  *
  * Gets the current breakpoint.
@@ -818,21 +647,6 @@ adw_breakpoint_bin_get_current_breakpoint (AdwBreakpointBin *self)
   return priv->current_breakpoint;
 }
 
-void
-adw_breakpoint_bin_set_warnings (AdwBreakpointBin *self,
-                                 gboolean          min_size_warnings,
-                                 gboolean          overflow_warnings)
-{
-  AdwBreakpointBinPrivate *priv;
-
-  g_return_if_fail (ADW_IS_BREAKPOINT_BIN (self));
-
-  priv = adw_breakpoint_bin_get_instance_private (self);
-
-  priv->enable_min_size_warnings = !!min_size_warnings;
-  priv->enable_overflow_warnings = !!overflow_warnings;
-}
-
 void
 adw_breakpoint_bin_set_warning_widget (AdwBreakpointBin *self,
                                        GtkWidget        *warning_widget)
@@ -857,33 +671,3 @@ adw_breakpoint_bin_has_breakpoints (AdwBreakpointBin *self)
 
   return !!priv->breakpoints;
 }
-
-void
-adw_breakpoint_bin_set_pass_through (AdwBreakpointBin *self,
-                                     gboolean          pass_through)
-{
-  AdwBreakpointBinPrivate *priv;
-
-  g_return_if_fail (ADW_IS_BREAKPOINT_BIN (self));
-
-  priv = adw_breakpoint_bin_get_instance_private (self);
-
-  priv->pass_through = !!pass_through;
-}
-
-void
-adw_breakpoint_bin_set_natural_size (AdwBreakpointBin *self,
-                                     int               width,
-                                     int               height)
-{
-  AdwBreakpointBinPrivate *priv;
-
-  g_return_if_fail (ADW_IS_BREAKPOINT_BIN (self));
-
-  priv = adw_breakpoint_bin_get_instance_private (self);
-
-  priv->natural_width = width;
-  priv->natural_height = height;
-
-  gtk_widget_queue_resize (GTK_WIDGET (self));
-}
